fn on_list(filepath: String, context: &mut Context, list: ListPacket) -> Status
Handle the list packet.

Arguments

  • filepath - The path to the directory where the files will be saved.
  • context - The receiver context.
  • list - The list packet containing the files to be transferred.

Returns

A Status representing the result of the operation.

Errors

Returns an error if the list packet is invalid or if a file with the same name already exists.