Struct caesar_core::receiver::client::File
source · struct File {
name: String,
size: u64,
progress: u64,
handle: File,
}Expand description
Represents a file to be transferred.
Fields
name: The name of the file.size: The total size of the file in bytes.progress: The number of bytes that have been transferred so far.handle: The file handle for reading and writing the file.
Fields
name: StringThe name of the file.
size: u64The total size of the file in bytes.
progress: u64The number of bytes that have been transferred so far.
handle: FileThe file handle for reading and writing the file.